@@ -1,3 +1,8 @@
+__author__ = 'Tim Michael Heinz Wolf'
+__version__ = '0.1.3'
+__license__ = 'MIT'
+__email__ = 'tim.wolf@mpi-hd.mpg.de'
+
 import glob
 import inspire_info
 
